==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation>Maillage</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Courbe sur maillage ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Courbe sur maillage</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation>Maillage</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Créer un maillage à partir d'une forme...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Tessellation de la forme</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation>Maillage</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Créer une section à partir d'un maillage et d'un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Section</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation>Maillage</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Ajuster le maillage avec un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Ajuste le maillage avec un plan</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Créer</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Fermer un fil</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Effacer</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Annuler</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Mauvaise maille choisie</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Aucun point n'a été sélectionné</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Courbe sur maillage</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Fil</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Tolerance d'accrochage aux sommets</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Seuil de séparation</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Approximation de Spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Tolérance pour mailler</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Continuité</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Angle de courbure maximal</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Début</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Tessellation</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Formes</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Options de maillage</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Définir les segments par les couleurs des faces</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Appliquer les couleurs des faces au maillage</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Déviation angulaire :</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Écart relatif de surface</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Longueur maximale d'arêtes:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Finesse :</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Très grossier</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Grossier</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Moyen</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Fin</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Très fin</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Défini par l'utilisateur</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Classement des tailles de maillages:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Eléments par arête:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Éléments par rayon de courbure :</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimiser la surface</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Éléments de second ordre</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Dominé par quadrilatères</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Réglages</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Déviation de surface :</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Longueur maximale d'arête :</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Sélectionner d'abord une forme pour le maillage.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Aucun document '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>Sélectionnez un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Veuillez sélectionner un plan à partir duquel sectionner le maillage.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>Sélectionnez un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Veuillez sélectionner un plan à partir duquel ajuster le maillage.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Maillage</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation>Maillage</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Courbe sur maillage ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Courbe sur maillage</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation>Maillage</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Créer un maillage à partir d'une forme...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Tessellation de la forme</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation>Maillage</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Créer une section à partir d'un maillage et d'un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Section</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation>Maillage</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Ajuster le maillage avec un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Ajuste le maillage avec un plan</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Créer</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Fermer un fil</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Effacer</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Annuler</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Mauvaise maille choisie</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Aucun point n'a été sélectionné</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Courbe sur maillage</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Fil</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Tolérance d'accrochage aux sommets</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Seuil de séparation</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Approximation de Spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Tolérance pour mailler</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Continuité</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Angle de courbure maximal</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Début</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Tessellation</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Formes</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Options de maillage</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Définir les segments par les couleurs des faces</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Appliquer les couleurs des faces au maillage</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Déviation angulaire :</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Écart relatif de surface</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Longueur maximale d'arêtes:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Finesse :</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Très grossier</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Grossier</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Moyen</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Fin</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Très fin</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Défini par l'utilisateur</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Classement des tailles de maillages:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Eléments par arête:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Éléments par rayon de courbure :</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Optimiser la surface</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Éléments de second ordre</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Dominé par quadrilatères</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Réglages</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Déviation de surface :</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Longueur maximale d'arête :</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Sélectionner d'abord une forme pour le maillage.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Aucun document '%1'.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Sélectionnez un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Veuillez sélectionner un plan à partir duquel sectionner le maillage.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Sélectionnez un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Veuillez sélectionner un plan à partir duquel ajuster le maillage.</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation>Coupé par un plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation>Sélectionnez le coté que vous souhaitez conserver.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>Intérieur</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Extérieur</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>Scinder</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Maillage</translation>
    </message>
  </context>
</TS>
